# Changelog

A summary of changes for PyAMG.

## [5.0.0]
- add AIR solver
- add and extend classical AMG interpolation routines
- add support for F/C relaxation
- add block strength measures
- refactor smoothing interface
- add advection examples to the gallery
- add pairwise aggregation

## [4.2.3]
- add joss paper
- update dostrings throughout
- address minor bugs
- update readthedocs
- remove pytest as an install requires
- improve testing/features in fem.py

## [4.2.2]
- update import for scipy 1.8
- add python 3.10 to CI
- fix up docstrings
